Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/sys/dev/sdmmc Add bus_rod. It use to change to Data Transfe...



details:   https://anonhg.NetBSD.org/src/rev/2d96c6337766
branches:  trunk
changeset: 757958:2d96c6337766
user:      kiyohara <kiyohara%NetBSD.org@localhost>
date:      Thu Oct 07 12:00:21 2010 +0000

description:
Add bus_rod.  It use to change to Data Transfer mode.

diffstat:

 sys/dev/sdmmc/sdmmcchip.h |  9 ++++++---
 1 files changed, 6 insertions(+), 3 deletions(-)

diffs (39 lines):

diff -r 25e86d84a665 -r 2d96c6337766 sys/dev/sdmmc/sdmmcchip.h
--- a/sys/dev/sdmmc/sdmmcchip.h Thu Oct 07 07:53:53 2010 +0000
+++ b/sys/dev/sdmmc/sdmmcchip.h Thu Oct 07 12:00:21 2010 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: sdmmcchip.h,v 1.2 2010/04/06 15:10:09 nonaka Exp $     */
+/*     $NetBSD: sdmmcchip.h,v 1.3 2010/10/07 12:00:21 kiyohara Exp $   */
 /*     $OpenBSD: sdmmcchip.h,v 1.3 2007/05/31 10:09:01 uwe Exp $       */
 
 /*
@@ -44,10 +44,11 @@
        /* write protect */
        int             (*write_protect)(sdmmc_chipset_handle_t);
 
-       /* bus power, clock frequency and width */
+       /* bus power, clock frequency, width and ROD(OpenDrain/PushPull) */
        int             (*bus_power)(sdmmc_chipset_handle_t, uint32_t);
        int             (*bus_clock)(sdmmc_chipset_handle_t, int);
        int             (*bus_width)(sdmmc_chipset_handle_t, int);
+       int             (*bus_rod)(sdmmc_chipset_handle_t, int);
 
        /* command execution */
        void            (*exec_command)(sdmmc_chipset_handle_t,
@@ -72,13 +73,15 @@
 /* write protect */
 #define sdmmc_chip_write_protect(tag, handle)                          \
        ((tag)->write_protect((handle)))
 /* bus power, clock frequency and width */
 #define sdmmc_chip_bus_power(tag, handle, ocr)                         \
        ((tag)->bus_power((handle), (ocr)))
 #define sdmmc_chip_bus_clock(tag, handle, freq)                                \
        ((tag)->bus_clock((handle), (freq)))
 #define sdmmc_chip_bus_width(tag, handle, width)                       \
        ((tag)->bus_width((handle), (width)))
+#define sdmmc_chip_bus_rod(tag, handle, width)                         \
+       ((tag)->bus_rod((handle), (width)))
 /* command execution */
 #define sdmmc_chip_exec_command(tag, handle, cmdp)                     \
        ((tag)->exec_command((handle), (cmdp)))
@@ -72,13 +73,15 @@
 #define sdmmc_chip_write_protect(tag, handle)                          \
        ((tag)->write_protect((handle)))
-/* bus power, clock frequency and width */
+/* bus power, clock frequency, width and rod */
 #define sdmmc_chip_bus_power(tag, handle, ocr)                         \
        ((tag)->bus_power((handle), (ocr)))



Home | Main Index | Thread Index | Old Index